pinax-wiki
========================

.. image:: https://travis-ci.org/pinax/pinax-wiki.png
    :target: https://travis-ci.org/pinax/pinax-wiki

.. image:: https://coveralls.io/repos/pinax/pinax-wiki/badge.png
    :target: https://coveralls.io/r/pinax/pinax-wiki

.. image:: https://pypip.in/d/pinax-wiki/badge.png
    :target:  https://pypi.python.org/pypi/pinax-wiki/

.. image:: https://pypip.in/v/pinax-wiki/badge.png
    :target:  https://pypi.python.org/pypi/pinax-wiki/

.. image:: https://pypip.in/license/pinax-wiki/badge.png
    :target:  https://pypi.python.org/pypi/pinax-wiki/


Welcome to the documentation for pinax-wiki!


Running the Tests
------------------------------------

You can run the tests with via::

    python setup.py test

or::

    make test

or::

    make all

or::

    python runtests.py

